==> nuntio_hera-0.1.0.tar.gz: lib/hera_app/send_reset_password_code_screen.dart <==
import 'package:flutter/material.dart';
import 'package:nuntio_hera/hera/hera.dart';
import 'package:nuntio_hera/hera_app/helpers.dart';
import 'package:nuntio_hera/hera_app/reset_password_screen.dart';
import 'package:nuntio_core/components/nuntio_text_field.dart';
import 'package:nuntio_core/models/hera.pb.dart';
import 'package:nuntio_core/components/iconed_button.dart';
import 'package:nuntio_core/components/nuntio_state_button.dart';
import 'hera_icons.dart';
import 'hera_localizations.dart';

class SendResetPasswordCodeScreen extends StatefulWidget {
  SendResetPasswordCodeScreen({
    Key? key,
    required this.config,
  });

  // config
  final Config config;

  @override
  State<SendResetPasswordCodeScreen> createState() =>
      _SendResetPasswordCodeScreenState();
}

class _SendResetPasswordCodeScreenState
    extends State<SendResetPasswordCodeScreen> {
  TextEditingController _textEditingController = TextEditingController();

  ButtonState _buttonState = ButtonState.idle;

  final _formKey = GlobalKey<FormState>();

  sendResetPasswordCode() {
    if (_formKey.currentState?.validate() == true) {
      if (validateEmail(_textEditingController.text)) {
        setState(() {
          _buttonState = ButtonState.loading;
        });
        Hera.sendResetPasswordEmail(email: _textEditingController.text)
            .then((value) => Navigator.of(context)
                .push(
                  MaterialPageRoute(
                    builder: (context) => ResetPasswordScreen(
                      config: widget.config,
                      expiresAt: value.expiresAt.toDateTime(),
                      userId: value.userId,
                    ),
                  ),
                )
                .then((value) => Navigator.of(context).pop()));
      } else if (validateMobile(_textEditingController.text)) {
        Hera.sendResetPasswordText(phoneNumber: _textEditingController.text)
            .then((value) => Navigator.of(context)
                .push(
                  MaterialPageRoute(
                    builder: (context) => ResetPasswordScreen(
                      config: widget.config,
                      expiresAt: value.expiresAt.toDateTime(),
                      userId: value.userId,
                    ),
                  ),
                )
                .then((value) => Navigator.of(context).pop()));
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SingleChildScrollView(
        child: Container(
          constraints: BoxConstraints(
              maxWidth: 500, minHeight: MediaQuery.of(context).size.height),
          child: SafeArea(
            child: Padding(
              padding: EdgeInsets.only(left: 20, right: 20, bottom: 20),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  SizedBox(
                    height: 100,
                    child: Image.network(widget.config.logo),
                  ),
                  Text(
                    HeraLocalizations.of(context).sendResetPasswordTitle,
                    style: Theme.of(context).textTheme.displayMedium,
                  ),
                  SizedBox(height: 10),
                  Text(
                    HeraLocalizations.of(context).sendResetPasswordSubtitle,
                    style: Theme.of(context).textTheme.headlineSmall,
                    textAlign: TextAlign.center,
                  ),
                  SizedBox(height: 30),
                  Form(
                    key: _formKey,
                    child: Column(
                      children: [
                        NuntioTextField(
                          validator: (value) {
                            if (value == null ||
                                value.isEmpty ||
                                (!validateMobile(value) &&
                                    !validateEmail(value))) {
                              return HeraLocalizations.of(context)
                                  .invalidIdentifierError;
                            }
                            return null;
                          },
                          prefix: HeraIcons.instance.identifier,
                          label: HeraLocalizations.of(context).identifierLabel,
                          hint: HeraLocalizations.of(context).identifierHint,
                          controller: _textEditingController,
                        ),
                      ],
                    ),
                  ),
                  SizedBox(height: 20),
                  SizedBox(
                    width: double.infinity,
                    height: Theme.of(context).buttonTheme.height,
                    child: NuntioStateButton.icon(
                      context,
                      iconedButtons: {
                        ButtonState.idle: IconedButton(
                          text: HeraLocalizations.of(context).next,
                          icon: Icon(
                            HeraIcons.instance.next,
                          ),
                          color: Theme.of(context).primaryColor,
                        ),
                        ButtonState.loading: IconedButton(
                          text: "",
                          color: Theme.of(context).primaryColor,
                        ),
                        ButtonState.fail: IconedButton(
                          text: HeraLocalizations.of(context).failure,
                          icon: Icon(Icons.cancel),
                          color: Colors.red.shade300,
                        ),
                        ButtonState.success: IconedButton(
                          text: HeraLocalizations.of(context).success,
                          icon: Icon(Icons.check_circle),
                          color: Colors.green.shade400,
                        )
                      },
                      state: _buttonState,
                      onPressed: () => sendResetPasswordCode(),
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.only(top: 10),
                    child: TextButton(
                      onPressed: () => Navigator.of(context).pop(),
                      child: Text(
                        HeraLocalizations.of(context).backToLogin,
                        style: TextStyle(
                          color: Theme.of(context).primaryColor,
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> nuntio_hera-0.1.10.tar.gz: lib/hera_app/send_reset_password_code_screen.dart <==
import 'package:flutter/material.dart';
import 'package:nuntio_hera/hera/hera.dart';
import 'package:nuntio_hera/hera_app/helpers.dart';
import 'package:nuntio_hera/hera_app/reset_password_screen.dart';
import 'package:nuntio_core/components/nuntio_text_field.dart';
import 'package:nuntio_core/models/hera.pb.dart';
import 'package:nuntio_core/components/iconed_button.dart';
import 'package:nuntio_core/components/nuntio_state_button.dart';
import 'hera_icons.dart';
import 'hera_localizations.dart';

class SendResetPasswordCodeScreen extends StatefulWidget {
  SendResetPasswordCodeScreen({
    Key? key,
    required this.config,
  });

  // config
  final HeraConfig config;

  @override
  State<SendResetPasswordCodeScreen> createState() =>
      _SendResetPasswordCodeScreenState();
}

class _SendResetPasswordCodeScreenState
    extends State<SendResetPasswordCodeScreen> {
  TextEditingController _textEditingController = TextEditingController();

  ButtonState _buttonState = ButtonState.idle;

  final _formKey = GlobalKey<FormState>();

  sendResetPasswordCode() {
    if (_formKey.currentState?.validate() == true) {
      if (validateEmail(_textEditingController.text)) {
        setState(() {
          _buttonState = ButtonState.loading;
        });
        Hera.sendResetPasswordEmail(email: _textEditingController.text)
            .then((value) => Navigator.of(context)
                .push(
                  MaterialPageRoute(
                    builder: (context) => ResetPasswordScreen(
                      config: widget.config,
                      expiresAt: value.expiresAt.toDateTime(),
                      userId: value.userId,
                    ),
                  ),
                )
                .then((value) => Navigator.of(context).pop()));
      } else if (validateMobile(_textEditingController.text)) {
        Hera.sendResetPasswordText(phoneNumber: _textEditingController.text)
            .then((value) => Navigator.of(context)
                .push(
                  MaterialPageRoute(
                    builder: (context) => ResetPasswordScreen(
                      config: widget.config,
                      expiresAt: value.expiresAt.toDateTime(),
                      userId: value.userId,
                    ),
                  ),
                )
                .then((value) => Navigator.of(context).pop()));
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SingleChildScrollView(
        child: Container(
          constraints: BoxConstraints(
              maxWidth: 500, minHeight: MediaQuery.of(context).size.height),
          child: SafeArea(
            child: Padding(
              padding: EdgeInsets.only(left: 20, right: 20, bottom: 20),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  SizedBox(
                    height: 100,
                    child: Image.network(widget.config.logo.url),
                  ),
                  Text(
                    HeraLocalizations.of(context).sendResetPasswordTitle,
                    style: Theme.of(context).textTheme.displayMedium,
                  ),
                  SizedBox(height: 10),
                  Text(
                    HeraLocalizations.of(context).sendResetPasswordSubtitle,
                    style: Theme.of(context).textTheme.headlineSmall,
                    textAlign: TextAlign.center,
                  ),
                  SizedBox(height: 30),
                  Form(
                    key: _formKey,
                    child: Column(
                      children: [
                        NuntioTextField(
                          validator: (value) {
                            if (value == null ||
                                value.isEmpty ||
                                (!validateMobile(value) &&
                                    !validateEmail(value))) {
                              return HeraLocalizations.of(context)
                                  .invalidIdentifierError;
                            }
                            return null;
                          },
                          prefix: HeraIcons.instance.identifier,
                          label: HeraLocalizations.of(context).identifierLabel,
                          hint: HeraLocalizations.of(context).identifierHint,
                          controller: _textEditingController,
                        ),
                      ],
                    ),
                  ),
                  SizedBox(height: 20),
                  SizedBox(
                    width: double.infinity,
                    height: Theme.of(context).buttonTheme.height,
                    child: NuntioStateButton.icon(
                      context,
                      iconedButtons: {
                        ButtonState.idle: IconedButton(
                          text: HeraLocalizations.of(context).next,
                          icon: Icon(
                            HeraIcons.instance.next,
                          ),
                          color: Theme.of(context).primaryColor,
                        ),
                        ButtonState.loading: IconedButton(
                          text: "",
                          color: Theme.of(context).primaryColor,
                        ),
                        ButtonState.fail: IconedButton(
                          text: HeraLocalizations.of(context).failure,
                          icon: Icon(Icons.cancel),
                          color: Colors.red.shade300,
                        ),
                        ButtonState.success: IconedButton(
                          text: HeraLocalizations.of(context).success,
                          icon: Icon(Icons.check_circle),
                          color: Colors.green.shade400,
                        )
                      },
                      state: _buttonState,
                      onPressed: () => sendResetPasswordCode(),
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.only(top: 10),
                    child: TextButton(
                      onPressed: () => Navigator.of(context).pop(),
                      child: Text(
                        HeraLocalizations.of(context).backToLogin,
                        style: TextStyle(
                          color: Theme.of(context).primaryColor,
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
